import React, { Component, useContext, useRef, useEffect } from 'react';
import PropTypes from 'prop-types';

var SET_SCALE = "SET_SCALE";
var SET_POSITION_X = "SET_POSITION_X";
var SET_POSITION_Y = "SET_POSITION_Y";
var SET_WRAPPER = "SET_WRAPPER";
var SET_CONTENT = "SET_CONTENT";
var SET_START_COORDS = "SET_START_COORDS";
var SET_IS_DOWN = "SET_IS_DOWN";
var SET_DISTANCE = "SET_DISTANCE";

var classCallCheck = function (instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
};

var createClass = function () {
  function defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  return function (Constructor, protoProps, staticProps) {
    if (protoProps) defineProperties(Constructor.prototype, protoProps);
    if (staticProps) defineProperties(Constructor, staticProps);
    return Constructor;
  };
}();

var _extends = Object.assign || function (target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i];

    for (var key in source) {
      if (Object.prototype.hasOwnProperty.call(source, key)) {
        target[key] = source[key];
      }
    }
  }

  return target;
};

var inherits = function (subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      enumerable: false,
      writable: true,
      configurable: true
    }
  });
  if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
};

var possibleConstructorReturn = function (self, call) {
  if (!self) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return call && (typeof call === "object" || typeof call === "function") ? call : self;
};

var defaultCoords = { x: 0, y: 0 };

var initialState = {
  sensitivity: 0.4,
  zoomOutSensitivity: 5,
  zoomInSensitivity: 5,
  dbClickSensitivity: 7,
  pinchSensitivity: 0.6,
  positionX: 0,
  positionY: 0,
  scale: 1,
  maxScale: 4,
  minScale: 0.8,
  maxPositionX: null,
  minPositionX: null,
  maxPositionY: null,
  minPositionY: null,
  limitToBounds: true,
  disabled: false,
  zoomingEnabled: true,
  panningEnabled: true,
  pinchEnabled: true,
  dbClickEnabled: true,
  transformEnabled: true,
  enableZoomedOutPanning: false,
  wrapperComponent: null,
  contentComponent: null,
  startCoords: defaultCoords,
  isDown: null,
  distance: null
};

var reducer = function reducer(state, action) {
  switch (action.type) {
    case SET_SCALE:
      return _extends({}, state, { scale: action.scale });
    case SET_POSITION_X:
      return _extends({}, state, { positionX: action.positionX });
    case SET_POSITION_Y:
      return _extends({}, state, { positionY: action.positionY });
    case SET_WRAPPER:
      return _extends({}, state, { wrapperComponent: action.wrapperComponent });
    case SET_CONTENT:
      return _extends({}, state, { contentComponent: action.contentComponent });
    case SET_START_COORDS:
      return _extends({}, state, { startCoords: action.startCoords });
    case SET_IS_DOWN:
      return _extends({}, state, { isDown: action.isDown });
    case SET_DISTANCE:
      return _extends({}, state, { distance: action.distance });
  }
};

/**
 * Rounds number to given decimal
 * eg. roundNumber(2.34343, 1) => 2.3
 */
var roundNumber = function roundNumber(num) {
  var decimal = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 5;

  return Number(num.toFixed(decimal));
};

/**
 * Checks if value is number, if not it returns default value
 * 1# eg. checkIsNumber(2, 30) => 2
 * 2# eg. checkIsNumber(null, 30) => 30
 */
var checkIsNumber = function checkIsNumber(num, defaultValue) {
  return typeof num === "number" ? num : defaultValue;
};

/**
 * Keeps value between given bounds, used for limiting view to given boundaries
 * 1# eg. boundLimiter(2, 0, 3, true) => 2
 * 2# eg. boundLimiter(4, 0, 3, true) => 3
 * 3# eg. boundLimiter(-2, 0, 3, true) => 0
 * 4# eg. boundLimiter(10, 0, 3, false) => 10
 */
var boundLimiter = function boundLimiter(value, minBound, maxBound, isActive) {
  if (!isActive) return value;
  if (value < minBound) return minBound;
  if (value > maxBound) return maxBound;
  return value;
};

/**
 * Returns relative coords of mouse on wrapper element, and provides
 * info about it's width, height, with same info about its content(zoomed component) element
 */
var relativeCoords = function relativeCoords(event, wrapperComponent, contentComponent, panningCase) {
  // mouse position x, y over wrapper component
  var x = event.offsetX || event.pageX;
  var y = event.offsetY || event.pageY;

  // Panning use mouse position over page because it works even when mouse is outside wrapper
  if (panningCase) {
    x = event.pageX;
    y = event.pageY;
  }

  // Mobile touch event case
  if (isNaN(x)) {
    var dist = getMidPagePosition(event.touches[0], event.touches[1] || event.touches[0]);
    var rect = wrapperComponent.getBoundingClientRect();

    x = dist.x - rect.x;
    y = dist.y - rect.y;
  }
  // sizes
  var wrapperWidth = wrapperComponent.offsetWidth;
  var wrapperHeight = wrapperComponent.offsetHeight;
  var contentRect = contentComponent.getBoundingClientRect();
  var contentWidth = contentRect.width;
  var contentHeight = contentRect.height;
  var diffHeight = wrapperHeight - contentHeight;
  var diffWidth = wrapperWidth - contentWidth;

  return {
    x: x,
    y: y,
    wrapperWidth: wrapperWidth,
    wrapperHeight: wrapperHeight,
    contentWidth: contentWidth,
    contentHeight: contentHeight,
    diffHeight: diffHeight,
    diffWidth: diffWidth
  };
};

/**
 * Calculate bounding area of zoomed/panned element
 */
var calculateBoundingArea = function calculateBoundingArea(wrapperWidth, contentWidth, diffWidth, wrapperHeight, contentHeight, diffHeight, enableZoomedOutPanning) {
  var scaleWidthFactor = wrapperWidth > contentWidth ? diffWidth * (enableZoomedOutPanning ? 1 : 0.5) : 0;
  var scaleHeightFactor = wrapperHeight > contentHeight ? diffHeight * (enableZoomedOutPanning ? 1 : 0.5) : 0;

  var minPositionX = wrapperWidth - contentWidth - scaleWidthFactor;
  var maxPositionX = 0 + scaleWidthFactor;
  var minPositionY = wrapperHeight - contentHeight - scaleHeightFactor;
  var maxPositionY = 0 + scaleHeightFactor;

  return { minPositionX: minPositionX, maxPositionX: maxPositionX, minPositionY: minPositionY, maxPositionY: maxPositionY };
};

/**
 * Returns middle coordinates x,y of two points
 * Used to get middle point of two fingers pinch
 */

var getMiddleCoords = function getMiddleCoords(firstPoint, secondPoint, wrapperComponent) {
  if (isNaN(firstPoint.x)) {
    var dist = getMidPagePosition(firstPoint, secondPoint);
    var rect = wrapperComponent.getBoundingClientRect();
    return {
      x: dist.x - rect.x,
      y: dist.y - rect.y
    };
  }
  return {
    x: (firstPoint.x + secondPoint.x) / 2,
    y: (firstPoint.y + secondPoint.y) / 2
  };
};

/**
 * Returns middle position of PageX for touch events
 */
var getMidPagePosition = function getMidPagePosition(firstPoint, secondPoint) {
  return {
    x: (firstPoint.clientX + secondPoint.clientX) / 2,
    y: (firstPoint.clientY + secondPoint.clientY) / 2
  };
};

/**
 * Returns distance between two points x,y
 */
var getDistance = function getDistance(firstPoint, secondPoint) {
  return Math.hypot(firstPoint.pageX - secondPoint.pageX, firstPoint.pageY - secondPoint.pageY);
};

/**
 * Delete undefined values from object keys
 * Used for deleting empty props
 */

var deleteInvalidProps = function deleteInvalidProps(value) {
  var newObject = _extends({}, value);
  Object.keys(newObject).forEach(function (key) {
    return newObject[key] == undefined && delete newObject[key];
  });
  return newObject;
};

// We want to make event listeners non-passive, and to do so have to check
// try {
//   const options = {
//     get passive() {
//       passiveSupported = true;
//     },
//   };
//   window.addEventListener("test", options, options);
//   window.removeEventListener("test", options, options);
// } catch {
//   passiveSupported = false;
// }

function makePassiveEventOption(passive) {
  return passive;
}

var Context = React.createContext({});

var StateProvider = function (_Component) {
  inherits(StateProvider, _Component);

  function StateProvider() {
    var _ref;

    var _temp, _this, _ret;

    classCallCheck(this, StateProvider);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = possibleConstructorReturn(this, (_ref = StateProvider.__proto__ || Object.getPrototypeOf(StateProvider)).call.apply(_ref, [this].concat(args))), _this), _this.state = _extends({}, initialState, _this.props.defaultValues), _this.handleZoom = function (event, setCenterClick, customDelta, customSensitivity) {
      var _this$state = _this.state,
          isDown = _this$state.isDown,
          zoomingEnabled = _this$state.zoomingEnabled,
          disabled = _this$state.disabled,
          wrapperComponent = _this$state.wrapperComponent,
          contentComponent = _this$state.contentComponent,
          positionX = _this$state.positionX,
          positionY = _this$state.positionY,
          scale = _this$state.scale,
          sensitivity = _this$state.sensitivity,
          maxScale = _this$state.maxScale,
          minScale = _this$state.minScale,
          enableZoomedOutPanning = _this$state.enableZoomedOutPanning,
          limitToBounds = _this$state.limitToBounds;

      if (isDown || !zoomingEnabled || disabled) return;
      event.preventDefault();
      event.stopPropagation();

      var _relativeCoords = relativeCoords(event, wrapperComponent, contentComponent),
          x = _relativeCoords.x,
          y = _relativeCoords.y,
          wrapperWidth = _relativeCoords.wrapperWidth,
          wrapperHeight = _relativeCoords.wrapperHeight;

      var deltaY = event ? event.deltaY < 0 ? 1 : -1 : 0;
      var delta = checkIsNumber(customDelta, deltaY);
      var zoomSensitivity = (customSensitivity || sensitivity) * 0.1;

      // Calculate new zoom
      var newScale = roundNumber(scale + delta * zoomSensitivity * scale, 2);

      if (!isNaN(maxScale) && newScale >= maxScale && scale < maxScale) {
        newScale = maxScale;
      }
      if (!isNaN(minScale) && newScale <= minScale && scale > minScale) {
        newScale = minScale;
      }
      if (!isNaN(maxScale) && !isNaN(minScale) && newScale > maxScale || newScale < minScale) return;

      var scaleDifference = newScale - scale;

      // Mouse position
      var mouseX = checkIsNumber(setCenterClick && setCenterClick.x, setCenterClick ? wrapperWidth / 2 : x);
      var mouseY = checkIsNumber(setCenterClick && setCenterClick.y, setCenterClick ? wrapperHeight / 2 : y);

      if (isNaN(mouseX) || isNaN(mouseY)) return console.warn("No mouse or touch offset found");

      // Determine new zoomed in point
      var newContentWidth = wrapperWidth * newScale;
      var newContentHeight = wrapperHeight * newScale;

      var newDiffWidth = wrapperWidth - newContentWidth;
      var newDiffHeight = wrapperHeight - newContentHeight;

      // Calculate bounding area

      var _calculateBoundingAre = calculateBoundingArea(wrapperWidth, newContentWidth, newDiffWidth, wrapperHeight, newContentHeight, newDiffHeight, enableZoomedOutPanning),
          minPositionX = _calculateBoundingAre.minPositionX,
          maxPositionX = _calculateBoundingAre.maxPositionX,
          minPositionY = _calculateBoundingAre.minPositionY,
          maxPositionY = _calculateBoundingAre.maxPositionY;

      _this.setScale(newScale);

      // Calculate new positions
      var newPositionX = -(mouseX * scaleDifference) + positionX;
      var newPositionY = -(mouseY * scaleDifference) + positionY;

      _this.setPositionX(boundLimiter(newPositionX, minPositionX, maxPositionX, limitToBounds));
      _this.setPositionY(boundLimiter(newPositionY, minPositionY, maxPositionY, limitToBounds));
    }, _this.handleStartPanning = function (event) {
      var _this$state2 = _this.state,
          isDown = _this$state2.isDown,
          panningEnabled = _this$state2.panningEnabled,
          disabled = _this$state2.disabled,
          wrapperComponent = _this$state2.wrapperComponent,
          contentComponent = _this$state2.contentComponent,
          positionX = _this$state2.positionX,
          positionY = _this$state2.positionY;
      var target = event.target;

      if (isDown || !panningEnabled || disabled || !wrapperComponent.contains(target) || event.touches && event.touches.length !== 1) return;
      var points = void 0;
      if (!event.touches) {
        points = relativeCoords(event, wrapperComponent, contentComponent, true);
      } else {
        points = getMiddleCoords(event.touches[0], event.touches[0], wrapperComponent);
      }
      _this.setStartCoords({
        x: points.x - positionX,
        y: points.y - positionY
      });
      _this.setIsDown(true);
    }, _this.handlePanning = function (event) {
      var _this$state3 = _this.state,
          isDown = _this$state3.isDown,
          panningEnabled = _this$state3.panningEnabled,
          disabled = _this$state3.disabled,
          wrapperComponent = _this$state3.wrapperComponent,
          contentComponent = _this$state3.contentComponent,
          startCoords = _this$state3.startCoords,
          enableZoomedOutPanning = _this$state3.enableZoomedOutPanning,
          limitToBounds = _this$state3.limitToBounds;

      if (!isDown || !panningEnabled || disabled || event.touches && event.touches.length !== 1) return;

      var _relativeCoords2 = relativeCoords(event, wrapperComponent, contentComponent, true),
          x = _relativeCoords2.x,
          y = _relativeCoords2.y,
          wrapperWidth = _relativeCoords2.wrapperWidth,
          wrapperHeight = _relativeCoords2.wrapperHeight,
          contentWidth = _relativeCoords2.contentWidth,
          contentHeight = _relativeCoords2.contentHeight,
          diffWidth = _relativeCoords2.diffWidth,
          diffHeight = _relativeCoords2.diffHeight;

      var newPositionX = x - startCoords.x;
      var newPositionY = y - startCoords.y;

      // Calculate bounding area

      var _calculateBoundingAre2 = calculateBoundingArea(wrapperWidth, contentWidth, diffWidth, wrapperHeight, contentHeight, diffHeight, enableZoomedOutPanning),
          minPositionX = _calculateBoundingAre2.minPositionX,
          maxPositionX = _calculateBoundingAre2.maxPositionX,
          minPositionY = _calculateBoundingAre2.minPositionY,
          maxPositionY = _calculateBoundingAre2.maxPositionY;

      _this.setPositionX(boundLimiter(newPositionX, minPositionX, maxPositionX, limitToBounds));
      _this.setPositionY(boundLimiter(newPositionY, minPositionY, maxPositionY, limitToBounds));
    }, _this.handleStopPanning = function () {
      _this.setIsDown(false);
    }, _this.handlePinchStart = function (event) {
      _this.handleStartPanning(event);
      event.preventDefault();
      event.stopPropagation();
    }, _this.handlePinch = function (event) {
      var _this$state4 = _this.state,
          distance = _this$state4.distance,
          pinchSensitivity = _this$state4.pinchSensitivity,
          pinchEnabled = _this$state4.pinchEnabled,
          disabled = _this$state4.disabled,
          wrapperComponent = _this$state4.wrapperComponent;

      _this.handlePanning(event);
      if (event.touches.length >= 2) {
        _this.handleStopPanning();
      }
      if (pinchEnabled && event.touches.length >= 2 && !disabled) {
        var _length = getDistance(event.touches[0], event.touches[1]);
        _this.setDistance(_length);
      }
      if (isNaN(distance) || event.touches.length !== 2 || !pinchEnabled || disabled) return;
      var length = getDistance(event.touches[0], event.touches[1]);
      _this.handleZoom(event, getMiddleCoords(event.touches[0], event.touches[1], wrapperComponent), distance < length ? 1 : -1, pinchSensitivity);
    }, _this.handlePinchStop = function () {
      var distance = _this.state.distance;

      _this.handleStopPanning();
      if (!isNaN(distance)) {
        _this.setDistance(false);
      }
    }, _this.zoomIn = function (event) {
      var _this$state5 = _this.state,
          zoomingEnabled = _this$state5.zoomingEnabled,
          disabled = _this$state5.disabled,
          zoomInSensitivity = _this$state5.zoomInSensitivity;

      if (!zoomingEnabled || disabled) return;
      _this.handleZoom(event, true, 1, zoomInSensitivity);
    }, _this.zoomOut = function (event) {
      var _this$state6 = _this.state,
          zoomingEnabled = _this$state6.zoomingEnabled,
          disabled = _this$state6.disabled,
          zoomOutSensitivity = _this$state6.zoomOutSensitivity;

      if (!zoomingEnabled || disabled) return;
      _this.handleZoom(event, true, -1, zoomOutSensitivity);
    }, _this.handleDbClick = function (event) {
      var _this$state7 = _this.state,
          zoomingEnabled = _this$state7.zoomingEnabled,
          disabled = _this$state7.disabled,
          dbClickSensitivity = _this$state7.dbClickSensitivity;

      if (!zoomingEnabled || disabled) return;
      //todo debug
      _this.handleZoom(event, false, 1, dbClickSensitivity);
    }, _this.setScale = function (scale) {
      _this.setState(function (state) {
        return reducer(state, { type: SET_SCALE, scale: scale });
      });
    }, _this.setPositionX = function (positionX) {
      _this.setState(function (state) {
        return reducer(state, { type: SET_POSITION_X, positionX: roundNumber(positionX, 3) });
      });
    }, _this.setPositionY = function (positionY) {
      _this.setState(function (state) {
        return reducer(state, { type: SET_POSITION_Y, positionY: roundNumber(positionY, 3) });
      });
    }, _this.setTransform = function (positionX, positionY, scale) {
      !isNaN(scale) && _this.setScale(scale);
      !isNaN(positionX) && _this.setPositionX(positionX);
      !isNaN(positionY) && _this.setPositionY(positionY);
    }, _this.resetTransform = function (defaultScale, defaultPositionX, defaultPositionY) {
      _this.setScale(checkIsNumber(defaultScale, initialState.scale));
      _this.setPositionX(checkIsNumber(defaultPositionX, initialState.positionX));
      _this.setPositionY(checkIsNumber(defaultPositionY, initialState.positionY));
    }, _this.setStartCoords = function (startCoords) {
      _this.setState(function (state) {
        return reducer(state, { type: SET_START_COORDS, startCoords: startCoords });
      });
    }, _this.setIsDown = function (isDown) {
      _this.setState(function (state) {
        return reducer(state, { type: SET_IS_DOWN, isDown: isDown });
      });
    }, _this.setDistance = function (distance) {
      _this.setState(function (state) {
        return reducer(state, { type: SET_DISTANCE, distance: distance });
      });
    }, _this.setWrapperComponent = function (wrapperComponent) {
      _this.setState(function (state) {
        return reducer(state, { type: SET_WRAPPER, wrapperComponent: wrapperComponent });
      });
    }, _this.setContentComponent = function (contentComponent) {
      _this.setState(function (state) {
        return reducer(state, { type: SET_CONTENT, contentComponent: contentComponent });
      });
    }, _temp), possibleConstructorReturn(_this, _ret);
  }

  createClass(StateProvider, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      var _this2 = this;

      var passiveOption = makePassiveEventOption(false);

      // Panning on window to allow panning when mouse is out of wrapper
      window.addEventListener("mousedown", this.handleStartPanning, passiveOption);
      window.addEventListener("mousemove", this.handlePanning, passiveOption);
      window.addEventListener("mouseup", this.handleStopPanning, passiveOption);
      return function () {
        window.removeEventListener("mousedown", _this2.handleStartPanning, passiveOption);
        window.removeEventListener("mousemove", _this2.handlePanning, passiveOption);
        window.removeEventListener("mouseup", _this2.handleStopPanning, passiveOption);
      };
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(oldProps, oldState) {
      var wrapperComponent = this.state.wrapperComponent;

      if (!oldState.wrapperComponent && this.state.wrapperComponent) {
        // Zooming events on wrapper
        var passiveOption = makePassiveEventOption(false);
        wrapperComponent.addEventListener("wheel", this.handleZoom, passiveOption);
        wrapperComponent.addEventListener("dblclick", this.handleDbClick, passiveOption);
        wrapperComponent.addEventListener("touchstart", this.handlePinchStart, passiveOption);
        wrapperComponent.addEventListener("touchmove", this.handlePinch, passiveOption);
        wrapperComponent.addEventListener("touchend", this.handlePinchStop, passiveOption);
      }
    }

    //////////
    // Zooming
    //////////

    //////////
    // Panning
    //////////

    //////////
    // Pinching
    //////////

    //////////
    // Controls
    //////////

    //////////
    // Setters
    //////////

  }, {
    key: "render",
    value: function render() {
      /**
       * Context provider value
       */
      var value = {
        state: {
          positionX: this.state.positionX,
          positionY: this.state.positionY,
          scale: this.state.scale,
          sensitivity: this.state.sensitivity,
          maxScale: this.state.maxScale,
          minScale: this.state.minScale,
          minPositionX: this.state.minPositionX,
          minPositionY: this.state.minPositionY,
          maxPositionX: this.state.maxPositionX,
          maxPositionY: this.state.maxPositionY,
          limitToBounds: this.state.limitToBounds,
          zoomingEnabled: this.state.zoomingEnabled,
          panningEnabled: this.state.panningEnabled,
          transformEnabled: this.state.transformEnabled,
          pinchEnabled: this.state.pinchEnabled,
          enableZoomedOutPanning: this.state.enableZoomedOutPanning,
          disabled: this.state.disabled,
          zoomOutSensitivity: this.state.zoomOutSensitivity,
          zoomInSensitivity: this.state.zoomInSensitivity,
          dbClickSensitivity: this.state.dbClickSensitivity,
          pinchSensitivity: this.state.pinchSensitivity,
          dbClickEnabled: this.state.dbClickEnabled
        },
        dispatch: {
          setScale: this.setScale,
          setPositionX: this.setPositionX,
          setPositionY: this.setPositionY,
          zoomIn: this.zoomIn,
          zoomOut: this.zoomOut,
          setTransform: this.setTransform,
          resetTransform: this.resetTransform
        },
        nodes: {
          setWrapperComponent: this.setWrapperComponent,
          setContentComponent: this.setContentComponent
        },
        internal: {
          handleZoom: this.handleZoom,
          handleStartPanning: this.handleStartPanning,
          handlePanning: this.handlePanning,
          handleStopPanning: this.handleStopPanning,
          handleDbClick: this.handleDbClick,
          handlePinchStart: this.handlePinchStart,
          handlePinch: this.handlePinch,
          handlePinchStop: this.handlePinchStop
        }
      };
      var children = this.props.children;

      var content = typeof children === "function" ? children(_extends({}, value.state, value.dispatch)) : children;

      return React.createElement(
        Context.Provider,
        { value: value },
        content
      );
    }
  }]);
  return StateProvider;
}(Component);

StateProvider.defaultProps = {
  defaultValues: {}
};

StateProvider.propTypes = {
  children: PropTypes.any,
  defaultValues: PropTypes.object
};

var TransformWrapper = function TransformWrapper(_ref) {
  var children = _ref.children,
      scale = _ref.scale,
      positionX = _ref.positionX,
      positionY = _ref.positionY,
      sensitivity = _ref.sensitivity,
      maxScale = _ref.maxScale,
      minScale = _ref.minScale,
      minPositionX = _ref.minPositionX,
      minPositionY = _ref.minPositionY,
      maxPositionX = _ref.maxPositionX,
      maxPositionY = _ref.maxPositionY,
      limitToBounds = _ref.limitToBounds,
      zoomingEnabled = _ref.zoomingEnabled,
      panningEnabled = _ref.panningEnabled,
      transformEnabled = _ref.transformEnabled,
      pinchEnabled = _ref.pinchEnabled,
      enableZoomedOutPanning = _ref.enableZoomedOutPanning,
      disabled = _ref.disabled,
      zoomOutSensitivity = _ref.zoomOutSensitivity,
      zoomInSensitivity = _ref.zoomInSensitivity,
      dbClickSensitivity = _ref.dbClickSensitivity,
      pinchSensitivity = _ref.pinchSensitivity,
      dbClickEnabled = _ref.dbClickEnabled;

  return React.createElement(
    StateProvider,
    {
      defaultValues: deleteInvalidProps({
        scale: scale,
        positionX: positionX,
        positionY: positionY,
        sensitivity: sensitivity,
        maxScale: maxScale,
        minScale: minScale,
        minPositionX: minPositionX,
        minPositionY: minPositionY,
        maxPositionX: maxPositionX,
        maxPositionY: maxPositionY,
        limitToBounds: limitToBounds,
        zoomingEnabled: zoomingEnabled,
        panningEnabled: panningEnabled,
        transformEnabled: transformEnabled,
        pinchEnabled: pinchEnabled,
        enableZoomedOutPanning: enableZoomedOutPanning,
        disabled: disabled,
        zoomOutSensitivity: zoomOutSensitivity,
        zoomInSensitivity: zoomInSensitivity,
        dbClickSensitivity: dbClickSensitivity,
        pinchSensitivity: pinchSensitivity,
        dbClickEnabled: dbClickEnabled
      })
    },
    children
  );
};

TransformWrapper.propTypes = {
  children: PropTypes.any,
  scale: PropTypes.number,
  positionX: PropTypes.number,
  positionY: PropTypes.number,
  sensitivity: PropTypes.number,
  maxScale: PropTypes.oneOfType([PropTypes.number, PropTypes.object]),
  minScale: PropTypes.oneOfType([PropTypes.number, PropTypes.object]),
  minPositionX: PropTypes.oneOfType([PropTypes.number, PropTypes.object]),
  maxPositionX: PropTypes.oneOfType([PropTypes.number, PropTypes.object]),
  minPositionY: PropTypes.oneOfType([PropTypes.number, PropTypes.object]),
  maxPositionY: PropTypes.oneOfType([PropTypes.number, PropTypes.object]),
  limitToBounds: PropTypes.bool,
  zoomingEnabled: PropTypes.bool,
  panningEnabled: PropTypes.bool,
  transformEnabled: PropTypes.bool,
  pinchEnabled: PropTypes.bool,
  enableZoomedOutPanning: PropTypes.bool,
  disabled: PropTypes.bool,
  zoomOutSensitivity: PropTypes.bool,
  zoomInSensitivity: PropTypes.bool,
  dbClickSensitivity: PropTypes.bool,
  pinchSensitivity: PropTypes.bool,
  dbClickEnabled: PropTypes.bool
};

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css = ".TransformComponent-module_container__3NwNd {\n  width: fit-content;\n  height: fit-content;\n  overflow: hidden;\n  -webkit-touch-callout: none; /* iOS Safari */\n  -webkit-user-select: none; /* Safari */\n  -khtml-user-select: none; /* Konqueror HTML */\n  -moz-user-select: none; /* Firefox */\n  -ms-user-select: none; /* Internet Explorer/Edge */\n  user-select: none;\n}\n.TransformComponent-module_content__TZU5O {\n  display: flex;\n  flex-wrap: wrap;\n  width: fit-content;\n  height: fit-content;\n  transform-origin: 0% 0%;\n}\n.TransformComponent-module_content__TZU5O img {\n  pointer-events: none;\n}\n";
var styles = { "container": "TransformComponent-module_container__3NwNd", "content": "TransformComponent-module_content__TZU5O" };
styleInject(css);

function TransformComponent(_ref) {
  var children = _ref.children;

  var wrapperRef = useRef(null);
  var contentRef = useRef(null);

  var _useContext = useContext(Context),
      state = _useContext.state,
      nodes = _useContext.nodes;

  var style = {
    transform: "translate(" + state.positionX + "px, " + state.positionY + "px) scale(" + state.scale + ")"
  };

  useEffect(function () {
    if (wrapperRef.current) {
      nodes.setWrapperComponent(wrapperRef.current);
    }
    if (contentRef.current) {
      nodes.setContentComponent(contentRef.current);
    }
  }, []);

  return React.createElement(
    "div",
    { ref: wrapperRef, className: "\"react-transform-component\" " + styles.container },
    React.createElement(
      "div",
      { ref: contentRef, className: "react-transform-element " + styles.content, style: style },
      children
    )
  );
}

TransformComponent.propTypes = { children: PropTypes.any };

export { TransformWrapper, TransformComponent };
//# sourceMappingURL=index.es.js.map
